@@ -24,8 +24,8 @@ def _f_expl_3_ssprk(x0, Y0, dx, *args, dYdx=None, **kwargs):
 
     Returns
     -------
-    Y1 : Field
-        New value of Y
+    dY : Field
+        Delta of variable to be integrated
 
     Butcher tableau
     ---------------
@@ -39,7 +39,7 @@ def _f_expl_3_ssprk(x0, Y0, dx, *args, dYdx=None, **kwargs):
     k1 = Y0.derivative(x0 + dx, Y0 + k0 * dx)
     k2 = Y0.derivative(x0 + c2*dx, Y0 + (a20*k0 + a21*k1)*dx)
 
-    return Y0 + dx*(b0*k0 + b1*k1 + b2*k2)
+    return dx*(b0*k0 + b1*k1 + b2*k2)
 
 
 expl_3_ssprk = Scheme(
