@@ -3,7 +3,7 @@ from simframe.integration.scheme import Scheme
 import numpy as np
 
 
-def _f_impl_2_midpoint_direct(x0, Y0, dx, *args, **kwargs):
+def _f_impl_2_midpoint_direct(x0, Y0, dx, jac=None, *args, **kwargs):
     """Implicit 2nd-order midpoint method with direct matrix inversion
 
     Parameters
@@ -14,6 +14,8 @@ def _f_impl_2_midpoint_direct(x0, Y0, dx, *args, **kwargs):
         Variable to be integrated at the beginning of scheme
     dx : IntVar
         Stepsize of integration variable
+    jac : Field, optional, defaul : None
+        Current Jacobian. Will be calculated, if not set
     args : additional positional arguments
     kwargs : additional keyworda arguments
 
@@ -28,15 +30,16 @@ def _f_impl_2_midpoint_direct(x0, Y0, dx, *args, **kwargs):
     -----|-----
          |  1 
     """
-    J = Y0.jacobian(x0+0.5*dx)          # Jacobian
-    N = J.shape[0]                      # Problem size
+    if jac is None:
+        jac = Y0.jacobian(x0+0.5*dx)    # Jacobian
+    N = jac.shape[0]                    # Problem size
     eye = np.eye(N)                     # Identity matrix
 
-    A = eye - 0.5*dx*J
+    A = eye - 0.5*dx*jac
     Ainv = np.linalg.inv(A)
-    k1 = np.dot(Ainv, np.dot(J, Y0))
+    k1 = np.dot(Ainv, np.dot(jac, Y0))
 
-    return Y0 + dx*k1
+    return dx*k1
 
 
 impl_2_midpoint_direct = Scheme(
